import type { SpecialTag, Track } from "@/types";

export default function useTrackColor() {
  const colors = ["red", "blue", "green"];
  const colorMap: Record<number, string> = {};

  function addTrackColorAttr(tList: Track[]): Track[] {
    let userIds: (number | undefined)[] = tList
      .map((v) => v.userId)
      .filter((x) => !!x);
    userIds = Array.from(new Set(userIds));
    const isByMultMark = userIds.length > 1;

    tList = tList.map((item) => {
      const uid = item.userId;
      if (item.headerMarkScore) {
        item.color = "green";
      } else {
        if (!colorMap[uid]) {
          colorMap[uid] = colors[Object.keys(colorMap).length] || "green";
        }
        item.color = colorMap[uid];
      }
      item.isByMultMark = isByMultMark;
      return item;
    });
    return tList;
  }

  function addSpecialTrackColorAttr(tList: SpecialTag[]): SpecialTag[] {
    return tList.map((item) => {
      item.color = colorMap[item.markerId] || "green";
      return item;
    });
  }

  function addHeaderTrackColorAttr(headerTrackList: any): any {
    return headerTrackList.map((item: any) => {
      item.color = "green";
      return item;
    });
  }

  return {
    addTrackColorAttr,
    addSpecialTrackColorAttr,
    addHeaderTrackColorAttr,
  };
}
